@@ -3,18 +3,21 @@
 Check that spiderosm is installed and functioning properly.
 '''
 
-import spiderosm.test
 import spiderosm.config
+import spiderosm.log
+import spiderosm.test
 
 #doit
 assert __name__ == "__main__"
-#get test data dir
-spiderosm.config.read_config_files()
 
 #run tests
 spiderosm.test.run_tests()
 
+#dump config
+spiderosm.log.info('config.info: %s', spiderosm.config.info)
+spiderosm.log.info('config.settings: %s', spiderosm.config.settings)
+
 #we only get here if all the tests pass.
-print 'Congratulations!  SpiderOSM appears to be properly installed and functioning.'
+spiderosm.log.info('Congratulations!  SpiderOSM appears to be properly installed and functioning.')
 
 
